*************************************************************************
* Setup
*************************************************************************
clear

/* Root filepath desired; default set to Mac users' downloads folder; please
change accordingly */
global root ~/Downloads

/* Name of dataset exported from Qualtrics; change "dataset_name" below as appropriate */
global measurement_raw dataset_name

cd $root

*************************************************************************
* Importing Data
*************************************************************************

/* Import; do-file assumes data exported from Qualtrics using choice text and with
viewing order data, as a TSV file; if a CSV file has been exported by the user
instead, please change the tsv extension below to csv */

* Import eliminates the second and third rows of Qualtrics data export, which contains
* metadata and descriptions for each question
import delimited using "$root/$measurement_raw.tsv", clear varnames(1) encoding ("utf-16") rowrange(4)

*Renaming Variables from Qualtrics Export

* NOTE: it is possible that when importing qsf file or copying questions from imported
* qsf file to a new survey, the question identifiers below may change. The user
* should change the question identifiers below that may have changed

rename (q3_pagesubmit q7_pagesubmit ///
q15_pagesubmit q19_1 q21_1 q23_1 ///
q25_pagesubmit q29_1 q31_1 q33_1 ///
q26_pagesubmit ///
q18_pagesubmit q20_1 v54 q22_1 ///
q29_pagesubmit v61 q32_1 v64) ///
(socialgroups_pres_timer allocs_instr_timer ///
univ_altru_left_timer orgmember_alloc_left domestic_alloc_left forgn_samelanguage_alloc_left ///
univ_altru_right_timer orgmember_alloc_right domestic_alloc_right forgn_samelanguage_alloc_right ///
trust_instr_timer ///
univ_trust_left_timer orgmember_trust_left domestic_trust_left forgn_samerace_trust_left ///
univ_trust_right_timer orgmember_trust_right domestic_trust_right forgn_samerace_trust_right)

* Drop other Qualtrics variables (click counts on screens, etc.)
drop q* fl*

* Importing with UTF-16 encoding imports all variables as string (though handles
* foreign language charactersm etc.), so we destring all numeric variables
destring, replace

*************************************************************************
* Processing Data
*************************************************************************

* Set total amount of money and trust points being split by respondents
global total_amount_money 100
global total_amount_points 100

********************** PROCESSING ALLOCATION DATA **********************

/*Since output from Qualtrics specifies the value of the slider, it represents
the amount of money or trust points allocated to the individual on the RIGHT of the slider;
as such, find allocation to the individual on the left (the in-groups) by
subtracting from 100, when respondent saw these on the left*/

* Money
local stranger_allocs orgmember_alloc_left domestic_alloc_left ///
forgn_samelanguage_alloc_left

foreach group of local stranger_allocs {
	replace `group' = $total_amount_money - `group'
}

* Trust
local stranger_trust orgmember_trust_left domestic_trust_left ///
forgn_samerace_trust_left

foreach group of local stranger_trusts {
	replace `group' = $total_amount_points - `group'
}

/*Generate variables depending on which presentation respondent saw*/

local socialgroups orgmember domestic

local foreigngroups_alloc forgn_samelanguage
local foreigngroups_trust forgn_samerace

foreach socialgroup of local socialgroups {
	gen `socialgroup'_alloc=.
	gen `socialgroup'_trust=.
}

foreach socialgroup of local foreigngroups_alloc {
	gen `socialgroup'_alloc=.
}

foreach socialgroup of local foreigngroups_trust {
	gen `socialgroup'_trust=.
}

gen univ_altru_timer=.
gen univ_trust_timer=.

/*Filling In*/
local variants left right
foreach variant of local variants {
	foreach socialgroup of `socialgroups' {
		replace `socialgroup'_alloc=`socialgroup'_alloc_`variant' / $total_amount_money if univ_altruism_on_`variant'==1
		replace `socialgroup'_trust=`socialgroup'_trust_`variant' / $total_amount_points if univ_trust_on_`variant'==1
	}

	foreach socialgroup of `foreigngroups_alloc' {
		replace `socialgroup'_alloc=`socialgroup'_alloc_`variant' / $total_amount_money if univ_altruism_on_`variant'==1
	}

	foreach socialgroup of `foreigngroups_trust' {
		replace `socialgroup'_trust=`socialgroup'_trust_`variant' / $total_amount_points if univ_trust_on_`variant'==1
	}	
	
	replace univ_altru_timer=univ_altru_`variant'_timer if univ_altruism_on_`variant'==1
	replace univ_trust_timer=univ_trust_`variant'_timer if univ_trust_on_`variant'==1
}

drop *_left_* *_right_* orgmember_alloc_left domestic_alloc_left forgn_samelanguage_alloc_left orgmember_alloc_right domestic_alloc_right forgn_samelanguage_alloc_right  orgmember_trust_left domestic_trust_left forgn_samerace_trust_left orgmember_trust_right domestic_trust_right forgn_samerace_trust_right

******************************************************************************
* CONSTRUCTING UNIVERSALISM MEASURES
******************************************************************************

* Construction universalism in altruism
gen universalism_altruism_domestic=orgmember_alloc
replace universalism_altruism_domestic=(1-universalism_altruism_domestic)*100

gen universalism_altruism_global=forgn_*_alloc
replace universalism_altruism_global=(1-universalism_altruism_global)*100

gen universalism_altruism_foreign=(1-domestic_alloc)*100

gen universalism_altruism_mean=(universalism_altruism_domestic + universalism_altruism_foreign + universalism_altruism_global)/3

* Construction universalism in trust
gen universalism_trust_domestic=orgmember_trust
replace universalism_trust_domestic=(1-universalism_trust_domestic)*100

gen universalism_trust_global=forgn_*_trust
replace universalism_trust_global=(1-universalism_trust_global)*100

gen universalism_trust_foreign=(1-domestic_trust)*100

gen universalism_trust_mean=(universalism_trust_domestic + universalism_trust_foreign + universalism_trust_global)/3

* Summary statistic
egen universalism_composite=rowmean(universalism_altruism_mean universalism_trust_mean)

* Standardizing dependent variables into z-scores
foreach measure in universalism_altruism_domestic universalism_altruism_global ///
universalism_altruism_foreign universalism_altruism_mean universalism_trust_domestic ///
universalism_trust_global universalism_trust_foreign universalism_trust_mean universalism_composite {

	egen s_`measure'=std(`measure')

}

* Label variables
do "$root/Measurement_Tools_Package/Do-Files/label_vars_short"
